==> xl-scale-ec2-plugin-4.0.0-sources.jar: com/xebialabs/deployit/plugin/ec2/ci/HostTemplate.java <==
package com.xebialabs.deployit.plugin.ec2.ci;

import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.concurrent.TimeoutException;

import org.jclouds.ec2.domain.RunningInstance;

import com.xebialabs.deployit.plugin.api.flow.Step;
import com.xebialabs.deployit.plugin.api.udm.ConfigurationItem;
import com.xebialabs.deployit.plugin.api.udm.Metadata;
import com.xebialabs.deployit.plugin.api.udm.Property;
import com.xebialabs.deployit.plugin.cloud.ci.BaseHostTemplate;
import com.xebialabs.deployit.plugin.cloud.step.WaitForInstancesStep;
import com.xebialabs.deployit.plugin.cloud.util.MarkerChecker;
import com.xebialabs.deployit.plugin.ec2.access.EC2Adapter;
import com.xebialabs.deployit.plugin.ec2.steps.CreateInstanceStep;
import com.xebialabs.deployit.plugin.ec2.steps.DestroyInstanceStep;
import com.xebialabs.deployit.plugin.ec2.util.EC2InstanceType;
import com.xebialabs.deployit.plugin.ec2.util.ServiceFactory;

import static com.google.common.base.Strings.isNullOrEmpty;
import static java.util.Arrays.asList;

@SuppressWarnings("serial")
@Metadata(description = "Amazon EC2 instance template", root = Metadata.ConfigurationItemRoot.CONFIGURATION)
public class HostTemplate extends BaseHostTemplate {

    @Property(required = true, label = "EC2 credentials", description = "The EC2 credentials to use when communicating with the AWS API.")
    private Credentials credentials;

    @Property(required = false, label = "Groups", description = "IDs of EC2 security groups to associate with the instance.")
    private Set<String> groups;

    @Property(required = false, label = "VPC subnet id", description = "The subnet ID for Amazon VPC within which to launch the image.")
    private String vpcSubnetId;

    @Property(required = true, label = "Image id (AMI)", description = "The Amazon Machine Image ID (AMI) to use when creating an instance.")
    private String ami;

    @Property(required = true, label = "Region", description = "The EC2 region to create the instance in (e.g., us-west-1 or eu-west-1)")
    private String region;

    @Property(required = true, label = "Instance type", description = "The EC2 instance type to create.")
    private EC2InstanceType instanceType;

    @Property(required = true, label = "Key pair", description = "Name of the EC2 key pair to use. It should be already present on EC2.")
    private String keyPair;

    @Property(required = false, label = "Tags", description = "EC2 tags ")
    private Map<String, String> tags;

    public EC2InstanceType getInstanceType() {
        return instanceType;
    }

    public String getKeyPair() {
        return keyPair;
    }

    public Set<String> getGroups() {
        return groups;
    }

    public String getVpcSubnetId() {
        return vpcSubnetId;
    }

    public String getAmi() {
        return ami;
    }

    public String getRegion() {
        return region;
    }

    public void setCredentials(final Credentials credentials) {
        this.credentials = credentials;
    }

    public Credentials getCredentials() {
        return credentials;
    }

    public Map<String, String> getTags() {
        return tags;
    }

    public void setTags(final Map<String, String> tags) {
        this.tags = tags;
    }

    public void setGroups(final Set<String> groups) {
        this.groups = groups;
    }

    public void setVpcSubnetId(String vpcSubnetId) {
        this.vpcSubnetId = vpcSubnetId;
    }

    public void setAmi(final String ami) {
        this.ami = ami;
    }

    public void setRegion(final String region) {
        this.region = region;
    }

    public void setInstanceType(final EC2InstanceType instanceType) {
        this.instanceType = instanceType;
    }

    public void setKeyPair(final String keyPair) {
        this.keyPair = keyPair;
    }

    @Override
    public List<? extends Step> produceCreateSteps(String envName, int instanceSeq) {
        String instanceLabel = instanceSeq == 0 ? envName : envName + " (" + getName() + ") #" + instanceSeq;
        return asList(new CreateInstanceStep(this, new EC2Adapter(getCredentials()), instanceLabel), new WaitForInstancesStep(new MarkerChecker()));
    }

    @Override
    public List<? extends Step> produceDestroySteps(ConfigurationItem instance) {
        return asList(new DestroyInstanceStep(instance, new ServiceFactory()));
    }

    @Override
    public String getInstanceIpAddress(String cloudId) {
        try {
            RunningInstance running = new EC2Adapter(getCredentials())
                    .waitForRunningInstance(getRegion(), cloudId, getBootTimeout(), getRetryDelay());

            // if we are connecting to a VPC, we need to return the *private* IP
            return isNullOrEmpty(vpcSubnetId) ? running.getIpAddress() : running.getPrivateIpAddress();
        } catch (TimeoutException e) {
            throw new RuntimeException(e);
        }
    }
}

==> xl-scale-ec2-plugin-4.0.1-sources.jar: com/xebialabs/deployit/plugin/ec2/ci/HostTemplate.java <==
package com.xebialabs.deployit.plugin.ec2.ci;

import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.concurrent.TimeoutException;

import org.jclouds.ec2.domain.RunningInstance;

import com.xebialabs.deployit.plugin.api.flow.Step;
import com.xebialabs.deployit.plugin.api.udm.ConfigurationItem;
import com.xebialabs.deployit.plugin.api.udm.Metadata;
import com.xebialabs.deployit.plugin.api.udm.Property;
import com.xebialabs.deployit.plugin.cloud.ci.BaseHostTemplate;
import com.xebialabs.deployit.plugin.cloud.step.WaitForInstancesStep;
import com.xebialabs.deployit.plugin.cloud.util.MarkerChecker;
import com.xebialabs.deployit.plugin.ec2.access.EC2Adapter;
import com.xebialabs.deployit.plugin.ec2.steps.CreateInstanceStep;
import com.xebialabs.deployit.plugin.ec2.steps.DestroyInstanceStep;
import com.xebialabs.deployit.plugin.ec2.util.EC2InstanceType;
import com.xebialabs.deployit.plugin.ec2.util.ServiceFactory;

import static com.google.common.base.Strings.isNullOrEmpty;
import static java.util.Arrays.asList;

@SuppressWarnings("serial")
@Metadata(description = "Amazon EC2 instance template", root = Metadata.ConfigurationItemRoot.CONFIGURATION)
public class HostTemplate extends BaseHostTemplate {

    @Property(required = true, label = "EC2 credentials", description = "The EC2 credentials to use when communicating with the AWS API.")
    private Credentials credentials;

    @Property(required = false, label = "Groups", description = "IDs of EC2 security groups to associate with the instance.")
    private Set<String> groups;

    @Property(required = false, label = "IAM Instance Profile ARN", description = "ARN of the IAM instance profile to associate with the instance.")
    private String iamInstanceProfileArn;

    @Property(required = false, label = "VPC subnet ID", description = "The subnet ID for Amazon VPC within which to launch the image.")
    private String vpcSubnetId;

    @Property(required = true, label = "Image ID (AMI)", description = "The Amazon Machine Image ID (AMI) to use when creating an instance.")
    private String ami;

    @Property(required = true, label = "Region", description = "The EC2 region to create the instance in (e.g., us-west-1 or eu-west-1)")
    private String region;

    @Property(required = true, label = "Instance type", description = "The EC2 instance type to create.")
    private EC2InstanceType instanceType;

    @Property(required = true, label = "Key pair", description = "Name of the EC2 key pair to use. It should be already present on EC2.")
    private String keyPair;

    @Property(required = false, label = "Tags", description = "EC2 tags ")
    private Map<String, String> tags;

    public EC2InstanceType getInstanceType() {
        return instanceType;
    }

    public String getKeyPair() {
        return keyPair;
    }

    public Set<String> getGroups() {
        return groups;
    }

    public String getIamInstanceProfileArn() {
        return iamInstanceProfileArn;
    }

    public String getVpcSubnetId() {
        return vpcSubnetId;
    }

    public String getAmi() {
        return ami;
    }

    public String getRegion() {
        return region;
    }

    public void setCredentials(final Credentials credentials) {
        this.credentials = credentials;
    }

    public Credentials getCredentials() {
        return credentials;
    }

    public Map<String, String> getTags() {
        return tags;
    }

    public void setTags(final Map<String, String> tags) {
        this.tags = tags;
    }

    public void setGroups(final Set<String> groups) {
        this.groups = groups;
    }

    public void setIamInstanceProfileArn(String iamInstanceProfileArn) {
        this.iamInstanceProfileArn = iamInstanceProfileArn;
    }

    public void setVpcSubnetId(String vpcSubnetId) {
        this.vpcSubnetId = vpcSubnetId;
    }

    public void setAmi(final String ami) {
        this.ami = ami;
    }

    public void setRegion(final String region) {
        this.region = region;
    }

    public void setInstanceType(final EC2InstanceType instanceType) {
        this.instanceType = instanceType;
    }

    public void setKeyPair(final String keyPair) {
        this.keyPair = keyPair;
    }

    @Override
    public List<? extends Step> produceCreateSteps(String envName, int instanceSeq) {
        String instanceLabel = instanceSeq == 0 ? envName : envName + " (" + getName() + ") #" + instanceSeq;
        return asList(new CreateInstanceStep(this, new EC2Adapter(getCredentials()), instanceLabel), new WaitForInstancesStep(new MarkerChecker()));
    }

    @Override
    public List<? extends Step> produceDestroySteps(ConfigurationItem instance) {
        return asList(new DestroyInstanceStep(instance, new ServiceFactory()));
    }

    @Override
    public String getInstanceIpAddress(String cloudId) {
        try {
            RunningInstance running = new EC2Adapter(getCredentials())
                    .waitForRunningInstance(getRegion(), cloudId, getBootTimeout(), getRetryDelay());

            // if we are connecting to a VPC, we need to return the *private* IP
            return isNullOrEmpty(vpcSubnetId) ? running.getIpAddress() : running.getPrivateIpAddress();
        } catch (TimeoutException e) {
            throw new RuntimeException(e);
        }
    }
}
